XPayElementCustomStyle class
Constructors
-
XPayElementCustomStyle({Map<
String, _InputFieldConfiguration> ? inputConfiguration, _InputStyle? inputStyle, _InputLabelStyle? inputLabelStyle, _OnFocusInputStyle? onFocusInputStyle, _InvalidStyle? invalidStyle, _ErrorMessageStyle? errorMessageStyle, Map<String, String> ? paymentMethodLabels, _PaymentMethodLabelStyle? paymentMethodLabelsStyle}) -
XPayElementCustomStyle.configureCustomStyle(Map<
String, dynamic> ? json) -
factory
Properties
- errorMessageStyle → _ErrorMessageStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputConfiguration
→ Map<
String, _InputFieldConfiguration> -
final
- inputLabelStyle → _InputLabelStyle
-
final
- inputStyle → _InputStyle
-
final
- invalidStyle → _InvalidStyle
-
final
- onFocusInputStyle → _OnFocusInputStyle
-
final
-
paymentMethodLabels
→ Map<
String, String> -
final
- paymentMethodLabelsStyle → _PaymentMethodLabelStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited